<?php
/*
Plugin Name: HanyBee Lazy YouTube
Description: عرض فيديو يوتيوب بصورة مصغرة بأعلى جودة، يتم تحميل الصورة تلقائيًا وتخزينها بصيغة WebP، مع تشغيل Lazy Load وتحكم كامل من لوحة التحكم.
Version: 1.2
Author: HanyBee
*/

// إنشاء صفحة الإعدادات
add_action('admin_menu', function() {
    add_menu_page('اعدادات YouTube', 'YouTube Lazy', 'manage_options', 'hanybee-lazy-youtube', 'hanybee_lazy_youtube_settings_page', 'dashicons-video-alt3');
});

function hanybee_lazy_youtube_settings_page() {
    ?>
    <div class="wrap">
        <h1>إعدادات HanyBee Lazy YouTube</h1>
        <form method="post" action="options.php">
            <?php
                settings_fields('hbyoutube_settings');
                do_settings_sections('hbyoutube_settings');
                submit_button();
            ?>
        </form>
    </div>
    <?php
}

add_action('admin_init', function() {
    register_setting('hbyoutube_settings', 'hbyoutube_save_locally');
    register_setting('hbyoutube_settings', 'hbyoutube_enable_webp');
    register_setting('hbyoutube_settings', 'hbyoutube_image_quality');

    add_settings_section('main_section', 'الخيارات العامة', null, 'hbyoutube_settings');

    add_settings_field('save_locally', 'تحميل الصورة إلى الموقع', function() {
        $val = get_option('hbyoutube_save_locally', 'yes');
        echo '<input type="checkbox" name="hbyoutube_save_locally" value="yes" ' . checked($val, 'yes', false) . '> نعم';
    }, 'hbyoutube_settings', 'main_section');

    add_settings_field('enable_webp', 'تحويل إلى WebP', function() {
        $val = get_option('hbyoutube_enable_webp', 'yes');
        echo '<input type="checkbox" name="hbyoutube_enable_webp" value="yes" ' . checked($val, 'yes', false) . '> نعم';
    }, 'hbyoutube_settings', 'main_section');

    add_settings_field('image_quality', 'جودة الصورة المصغرة', function() {
        $val = get_option('hbyoutube_image_quality', 'maxres');
        echo '<select name="hbyoutube_image_quality">
            <option value="maxres" ' . selected($val, 'maxres', false) . '>Max Res (1280x720)</option>
            <option value="sd" ' . selected($val, 'sd', false) . '>SD (640x480)</option>
            <option value="hq" ' . selected($val, 'hq', false) . '>HQ (480x360)</option>
        </select>';
    }, 'hbyoutube_settings', 'main_section');
});

// استبدال oEmbed تلقائيًا
add_filter('embed_oembed_html', 'hbyoutube_oembed_replace', 10, 4);
function hbyoutube_oembed_replace($html, $url, $attr, $post_ID) {
    if (strpos($url, 'youtube.com/watch') === false && strpos($url, 'youtu.be/') === false) {
        return $html;
    }

    preg_match('/(?:youtube\.com\/watch\?v=|youtu\.be\/)([\w-]+)/', $url, $matches);
    if (!isset($matches[1])) return $html;

    $id = $matches[1];
    $filename = sanitize_file_name($id);
    $upload_dir = wp_upload_dir();
    $local_path = $upload_dir['basedir'] . "/youtube-thumbs/{$filename}.jpg";
    $webp_path  = $upload_dir['basedir'] . "/youtube-thumbs/{$filename}.webp";
    $final_url  = "";
    $alt_text = 'مشاهدة فيديو يوتيوب'; // نص alt ثابت الآن

    $quality = get_option('hbyoutube_image_quality', 'maxres');
    $quality_map = [
        'maxres' => 'maxresdefault',
        'sd' => 'sddefault',
        'hq' => 'hqdefault'
    ];
    $thumb_name = $quality_map[$quality] ?? 'hqdefault';

    if (get_option('hbyoutube_save_locally') === 'yes') {
        if (!file_exists($local_path)) {
            $img_url = "https://img.youtube.com/vi/{$id}/{$thumb_name}.jpg";
            $img = @file_get_contents($img_url);
            if ($img) {
                if (!file_exists(dirname($local_path))) mkdir(dirname($local_path), 0755, true);
                file_put_contents($local_path, $img);
            }
        }

        if (get_option('hbyoutube_enable_webp') === 'yes' && function_exists('imagewebp') && file_exists($local_path) && !file_exists($webp_path)) {
            $image = imagecreatefromjpeg($local_path);
            if ($image) imagewebp($image, $webp_path);
        }

        $final_url = file_exists($webp_path) ? $upload_dir['baseurl'] . "/youtube-thumbs/{$filename}.webp" : (file_exists($local_path) ? $upload_dir['baseurl'] . "/youtube-thumbs/{$filename}.jpg" : '');
    } else {
        $final_url = "https://img.youtube.com/vi/{$id}/{$thumb_name}.jpg";
    }

    ob_start();
    ?>
    <div class="hbyoutube-wrapper" style="aspect-ratio:16/9; position:relative; cursor:pointer;" data-id="<?php echo esc_attr($id); ?>">
        <?php if (!empty($final_url)) : ?>
            <img src="<?php echo esc_url($final_url); ?>" alt="<?php echo esc_attr($alt_text); ?>" loading="lazy" style="width:100%; height:auto; display:block;">
        <?php else : ?>
            <img src="<?php echo esc_url(plugins_url('assets/placeholder.webp', __FILE__)); ?>" alt="صورة افتراضية" loading="lazy" style="width:100%; height:auto; display:block;">
        <?php endif; ?>
        <div style="position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);">
            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100" width="80" height="80">
                <circle cx="50" cy="50" r="48" fill="rgba(0,0,0,0.6)" />
                <polygon points="40,30 70,50 40,70" fill="#fff" />
            </svg>
        </div>
    </div>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            document.querySelectorAll('.hbyoutube-wrapper').forEach(function (el) {
                el.addEventListener('click', function () {
                    const id = el.dataset.id;
                    const iframe = document.createElement('iframe');
                    iframe.src = 'https://www.youtube.com/embed/' + id + '?autoplay=1';
                    iframe.allow = 'accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture';
                    iframe.allowFullscreen = true;
                    iframe.style.width = '100%';
                    iframe.style.height = '100%';
                    iframe.style.border = 'none';
                    el.innerHTML = '';
                    el.appendChild(iframe);
                });
            });
        });
    </script>
    <?php
    return ob_get_clean();
}
?>
